import os
from pathlib import PurePath
from tests.integration_tests.validation.conformance_suite_config import (
    CONFORMANCE_SUITE_PATH_PREFIX, ConformanceSuiteConfig
)

TIMING = {f'inlineXBRL-1.1-conformanceSuite-2020-04-08/tests/{k}': v for k, v in {
    'baseURIs/FAIL-baseURI-on-ix-header.xml': 0.058,
    'baseURIs/FAIL-baseURI-on-xhtml.xml': 0.046,
    'baseURIs/PASS-baseURI-on-ix-references-multiRefs.xml': 0.075,
    'continuation/FAIL-continuation-duplicate-id.xml': 0.054,
    'continuation/FAIL-continuation-nonNumeric-circular.xml': 0.053,
    'continuation/FAIL-continuation-nonNumeric-circular2.xml': 0.056,
    'continuation/FAIL-continuation-nonNumeric-invalid-nesting-2.xml': 0.055,
    'continuation/FAIL-continuation-nonNumeric-invalid-nesting.xml': 0.053,
    'continuation/FAIL-continuation-nonNumeric-self.xml': 0.054,
    'continuation/FAIL-continuation-orphaned-cycle.xml': 0.054,
    'continuation/FAIL-continuation-used-twice.xml': 0.052,
    'continuation/FAIL-footnote-continuation-invalid-nesting-2.xml': 0.054,
    'continuation/FAIL-footnote-continuation-invalid-nesting.xml': 0.053,
    'continuation/FAIL-nonNumeric-dangling-continuation-2.xml': 0.053,
    'continuation/FAIL-nonNumeric-dangling-continuation.xml': 0.056,
    'continuation/FAIL-orphaned-continuation.xml': 0.045,
    'continuation/PASS-nonNumeric-continuation-multiple-documents.xml': 0.096,
    'continuation/PASS-nonNumeric-continuation-other-descendants-escaped.xml': 0.063,
    'continuation/PASS-nonNumeric-continuation-other-descendants.xml': 0.061,
    'continuation/PASS-nonNumeric-continuation-out-of-order.xml': 0.063,
    'continuation/PASS-nonNumeric-continuation-transform.xml': 0.059,
    'continuation/PASS-nonNumeric-continuation.xml': 0.077,
    'exclude/FAIL-exclude-nonFraction-parent.xml': 0.057,
    'exclude/FAIL-misplaced-exclude.xml': 0.045,
    'exclude/PASS-element-ix-exclude-complete.xml': 1.484,
    'exclude/PASS-exclude-nonNumeric-parent.xml': 0.103,
    'exclude/PASS-multiple-excludes-nonNumeric-parent.xml': 0.064,
    'footnotes/FAIL-element-ix-footnote-04.xml': 1.314,
    'footnotes/FAIL-footnote-any-attribute.xml': 0.057,
    'footnotes/FAIL-footnote-dangling-continuation.xml': 0.048,
    'footnotes/FAIL-footnote-dangling-fromRef.xml': 0.055,
    'footnotes/FAIL-footnote-dangling-toRef.xml': 0.053,
    'footnotes/FAIL-footnote-duplicate-footnoteIDs-different-input-docs.xml': 0.096,
    'footnotes/FAIL-footnote-duplicate-footnoteIDs.xml': 0.056,
    'footnotes/FAIL-footnote-invalid-element-content.xml': 0.046,
    'footnotes/FAIL-footnote-missing-footnoteID.xml': 0.055,
    'footnotes/PASS-element-ix-footnote-03.xml': 1.529,
    'footnotes/PASS-element-link-footnote-02.xml': 1.557,
    'footnotes/PASS-element-link-footnote-complete-role-defs.xml': 0.065,
    'footnotes/PASS-element-link-footnote-complete.xml': 1.571,
    'footnotes/PASS-element-link-footnote-footnoteArcrole-2.xml': 1.565,
    'footnotes/PASS-element-link-footnote-footnoteArcrole.xml': 0.063,
    'footnotes/PASS-element-link-footnote-footnoteLinkRole-2.xml': 1.602,
    'footnotes/PASS-element-link-footnote-footnoteLinkRole.xml': 0.066,
    'footnotes/PASS-element-link-footnote-footnoteRole-2.xml': 1.643,
    'footnotes/PASS-element-link-footnote-footnoteRole.xml': 0.069,
    'footnotes/PASS-element-link-footnote-nonNumeric-escaped.xml': 1.610,
    'footnotes/PASS-element-link-footnote-nonNumeric-unescaped.xml': 1.570,
    'footnotes/PASS-element-link-footnote-nothidden.xml': 1.547,
    'footnotes/PASS-element-link-footnote-resolved-uris.xml': 1.566,
    'footnotes/PASS-element-link-footnote-xhtml-content-exclude.xml': 1.598,
    'footnotes/PASS-element-link-footnote-xhtml-content.xml': 1.584,
    'footnotes/PASS-elements-footnote-and-nonNumeric-unresolvable-uris-in-exclude.xml': 1.584,
    'footnotes/PASS-footnote-any-attribute.xml': 0.065,
    'footnotes/PASS-footnote-continuation.xml': 0.064,
    'footnotes/PASS-footnote-footnoteLinkRole-multiple-output.xml': 0.129,
    'footnotes/PASS-footnote-footnoteRole-multiple-output.xml': 0.128,
    'footnotes/PASS-footnote-ix-element-content.xml': 0.064,
    'footnotes/PASS-footnote-ix-exclude-content.xml': 0.061,
    'footnotes/PASS-footnote-nested-ix-element-content.xml': 0.065,
    'footnotes/PASS-footnote-nested-xml-base-decls.xml': 0.063,
    'footnotes/PASS-footnote-on-nonFraction.xml': 0.061,
    'footnotes/PASS-footnote-order-attribute.xml': 0.062,
    'footnotes/PASS-footnote-relative-uris-object-tag.xml': 0.065,
    'footnotes/PASS-footnote-uris-with-spaces.xml': 0.062,
    'footnotes/PASS-footnote-valid-element-content.xml': 0.065,
    'footnotes/PASS-footnote-within-footnote.xml': 0.065,
    'footnotes/PASS-footnote-xml-base-xhtml-base-no-interaction.xml': 0.065,
    'footnotes/PASS-footnoteArcrole-multiple-output.xml': 0.128,
    'footnotes/PASS-footnoteRef-on-fraction.xml': 0.063,
    'footnotes/PASS-footnoteRef-on-nonNumeric.xml': 0.061,
    'footnotes/PASS-footnoteRef-on-tuple.xml': 0.061,
    'footnotes/PASS-many-to-one-footnote-complete.xml': 0.064,
    'footnotes/PASS-many-to-one-footnote-different-arcroles.xml': 0.064,
    'footnotes/PASS-many-to-one-footnotes-multiple-outputs.xml': 0.186,
    'footnotes/PASS-multiple-outputs-check-dont-have-empty-footnoteLinks.xml': 0.126,
    'footnotes/PASS-two-footnotes-multiple-output.xml': 0.128,
    'footnotes/PASS-unused-footnote.xml': 0.063,
    'format/FAIL-format-numdash-badContent.xml': 0.052,
    'format/FAIL-ix-format-undefined.xml': 3.245,
    'format/PASS-element-ix-nonFraction-ixt-num-nodecimals.xml': 1.519,
    'format/PASS-format-numdash.xml': 0.065,
    'fraction/FAIL-fraction-denominator-empty.xml': 0.052,
    'fraction/FAIL-fraction-denominator-illegal-child-node.xml': 0.053,
    'fraction/FAIL-fraction-denominator-ix-format-expanded-name-mismatch.xml': 0.054,
    'fraction/FAIL-fraction-denominator-ix-format-invalid.xml': 0.045,
    'fraction/FAIL-fraction-denominator-ix-sign-invalid.xml': 0.053,
    'fraction/FAIL-fraction-illegal-content.xml': 0.052,
    'fraction/FAIL-fraction-illegal-nesting-unitRef.xml': 0.055,
    'fraction/FAIL-fraction-illegal-nesting-xsi-nil-2.xml': 0.052,
    'fraction/FAIL-fraction-illegal-nesting-xsi-nil.xml': 0.053,
    'fraction/FAIL-fraction-illegal-nesting.xml': 0.052,
    'fraction/FAIL-fraction-ix-any-attribute.xml': 0.051,
    'fraction/FAIL-fraction-ix-contextRef-unresolvable.xml': 0.055,
    'fraction/FAIL-fraction-ix-footnoteRef-unresolvable.xml': 0.047,
    'fraction/FAIL-fraction-ix-tupleRef-attr-tuple-missing.xml': 0.053,
    'fraction/FAIL-fraction-ix-unitRef-unresolvable.xml': 0.054,
    'fraction/FAIL-fraction-missing-contextRef.xml': 0.044,
    'fraction/FAIL-fraction-missing-denominator.xml': 0.054,
    'fraction/FAIL-fraction-missing-numerator-and-denominator.xml': 0.053,
    'fraction/FAIL-fraction-missing-numerator.xml': 0.048,
    'fraction/FAIL-fraction-missing-unitRef.xml': 0.053,
    'fraction/FAIL-fraction-multiple-denominators.xml': 0.051,
    'fraction/FAIL-fraction-multiple-numerators.xml': 0.050,
    'fraction/FAIL-fraction-no-format-negative-number.xml': 0.049,
    'fraction/FAIL-fraction-numerator-denominator-non-xsi-attributes.xml': 0.055,
    'fraction/FAIL-fraction-numerator-empty.xml': 0.046,
    'fraction/FAIL-fraction-numerator-illegal-child-node.xml': 0.052,
    'fraction/FAIL-fraction-numerator-ix-format-expanded-name-mismatch.xml': 0.099,
    'fraction/FAIL-fraction-numerator-ix-format-invalid.xml': 0.048,
    'fraction/FAIL-fraction-numerator-ix-sign-invalid.xml': 0.054,
    'fraction/FAIL-fraction-rule-no-other-ixDescendants.xml': 0.045,
    'fraction/FAIL-fraction-rule-no-xbrli-attributes.xml': 0.051,
    'fraction/PASS-attribute-ix-format-denominator-01.xml': 3.623,
    'fraction/PASS-attribute-ix-format-numerator-01.xml': 3.677,
    'fraction/PASS-attribute-ix-name-fraction-01.xml': 3.701,
    'fraction/PASS-attribute-ix-scale-denominator-01.xml': 3.706,
    'fraction/PASS-attribute-ix-scale-denominator-04.xml': 3.752,
    'fraction/PASS-attribute-ix-scale-numerator-01.xml': 3.719,
    'fraction/PASS-attribute-ix-scale-numerator-04.xml': 3.696,
    'fraction/PASS-attribute-ix-sign-denominator-01.xml': 3.738,
    'fraction/PASS-attribute-ix-sign-numerator-01.xml': 3.712,
    'fraction/PASS-fraction-denominator-ix-format-expanded-name-match.xml': 0.064,
    'fraction/PASS-fraction-denominator-ix-format.xml': 0.060,
    'fraction/PASS-fraction-denominator-ix-sign-scale-valid.xml': 0.062,
    'fraction/PASS-fraction-ix-order-attr.xml': 0.065,
    'fraction/PASS-fraction-ix-target-attr.xml': 0.120,
    'fraction/PASS-fraction-ix-tupleRef-attr.xml': 0.061,
    'fraction/PASS-fraction-nesting-2.xml': 0.060,
    'fraction/PASS-fraction-nesting-3.xml': 0.062,
    'fraction/PASS-fraction-nesting-4.xml': 0.058,
    'fraction/PASS-fraction-nesting.xml': 0.062,
    'fraction/PASS-fraction-non-ix-any-attribute.xml': 0.064,
    'fraction/PASS-fraction-numerator-denominator-xsi-attributes.xml': 0.062,
    'fraction/PASS-fraction-numerator-ix-format-expanded-name-match.xml': 0.061,
    'fraction/PASS-fraction-numerator-ix-format.xml': 0.062,
    'fraction/PASS-fraction-numerator-ix-sign-valid.xml': 0.059,
    'fraction/PASS-fraction-xsi-nil.xml': 0.061,
    'fraction/PASS-ix-denominator-01.xml': 3.737,
    'fraction/PASS-ix-denominator-02.xml': 3.744,
    'fraction/PASS-ix-denominator-03.xml': 3.755,
    'fraction/PASS-ix-denominator-04.xml': 3.730,
    'fraction/PASS-ix-numerator-04.xml': 3.748,
    'fraction/PASS-simple-fraction-with-html-children.xml': 0.062,
    'fraction/PASS-simple-fraction.xml': 0.061,
    'header/FAIL-ix-header-child-of-html-header.xml': 0.054,
    'header/FAIL-misplaced-ix-element-in-context.xml': 0.054,
    'header/FAIL-missing-header.xml': 0.000,
    'header/PASS-header-content-split-over-input-docs.xml': 0.100,
    'header/PASS-header-empty.xml': 0.107,
    'header/PASS-single-ix-header-muli-input.xml': 0.099,
    'hidden/FAIL-empty-hidden.xml': 0.056,
    'hidden/FAIL-hidden-empty-tuple-content.xml': 0.046,
    'hidden/FAIL-hidden-illegal-content.xml': 0.054,
    'hidden/FAIL-hidden-incorrect-order-in-header.xml': 0.054,
    'hidden/FAIL-hidden-not-header-descendant.xml': 0.050,
    'hidden/PASS-hidden-nonFraction-content.xml': 0.063,
    'hidden/PASS-hidden-tuple-content.xml': 0.065,
    'html/FAIL-a-name-attribute.xml': 0.058,
    'html/FAIL-charset-on-meta.xml': 0.054,
    'html/FAIL-empty-class-attribute.xml': 0.057,
    'ids/FAIL-id-triplication.xml': 0.047,
    'ids/FAIL-non-unique-id-context.xml': 0.095,
    'ids/FAIL-non-unique-id-footnote.xml': 0.053,
    'ids/FAIL-non-unique-id-fraction.xml': 0.089,
    'ids/FAIL-non-unique-id-nonFraction.xml': 0.094,
    'ids/FAIL-non-unique-id-nonNumeric.xml': 0.091,
    'ids/FAIL-non-unique-id-references.xml': 0.054,
    'ids/FAIL-non-unique-id-tuple.xml': 0.096,
    'ids/FAIL-non-unique-id-unit.xml': 0.088,
    'multiIO/FAIL-multi-input-duplicate-context-ids.xml': 0.092,
    'multiIO/FAIL-multi-input-duplicate-unit-ids.xml': 0.093,
    'multiIO/FAIL-two-inputs-each-with-error.xml': 0.091,
    'multiIO/FAIL-two-nonIXBRL-inputs.xml': 0.001,
    'multiIO/PASS-double-input-single-output.xml': 0.108,
    'multiIO/PASS-ix-references-06.xml': 3.289,
    'multiIO/PASS-ix-references-07.xml': 3.291,
    'multiIO/PASS-multiple-input-multiple-output.xml': 0.211,
    'multiIO/PASS-single-input-double-output.xml': 0.126,
    'multiIO/PASS-single-input.xml': 0.060,
    'nonFraction/FAIL-nonFraction-IXBRLelement-content.xml': 0.057,
    'nonFraction/FAIL-nonFraction-any-ix-attribute.xml': 0.056,
    'nonFraction/FAIL-nonFraction-decimals-and-precision-attrs.xml': 0.140,
    'nonFraction/FAIL-nonFraction-double-nesting.xml': 0.057,
    'nonFraction/FAIL-nonFraction-empty-content.xml': 0.047,
    'nonFraction/FAIL-nonFraction-empty-without-xsi-nil.xml': 0.056,
    'nonFraction/FAIL-nonFraction-invalid-sign-attr.xml': 0.052,
    'nonFraction/FAIL-nonFraction-ix-format-expanded-name-mismatch.xml': 0.056,
    'nonFraction/FAIL-nonFraction-ix-format-invalid-minus-sign.xml': 0.050,
    'nonFraction/FAIL-nonFraction-ix-format-invalid.xml': 0.055,
    'nonFraction/FAIL-nonFraction-missing-context-attr.xml': 0.054,
    'nonFraction/FAIL-nonFraction-missing-name-attr.xml': 0.055,
    'nonFraction/FAIL-nonFraction-missing-unit-attr.xml': 0.048,
    'nonFraction/FAIL-nonFraction-mixed-nesting-2.xml': 0.055,
    'nonFraction/FAIL-nonFraction-mixed-nesting-3.xml': 0.051,
    'nonFraction/FAIL-nonFraction-mixed-nesting.xml': 0.056,
    'nonFraction/FAIL-nonFraction-neither-decimals-nor-precision-attrs.xml': 0.055,
    'nonFraction/FAIL-nonFraction-nesting-format-mismatch-2.xml': 0.053,
    'nonFraction/FAIL-nonFraction-nesting-format-mismatch.xml': 0.053,
    'nonFraction/FAIL-nonFraction-nesting-scale-mismatch-2.xml': 0.054,
    'nonFraction/FAIL-nonFraction-nesting-scale-mismatch.xml': 0.054,
    'nonFraction/FAIL-nonFraction-nesting-unitRef-mismatch.xml': 0.055,
    'nonFraction/FAIL-nonFraction-nesting-xsi-nil.xml': 0.057,
    'nonFraction/FAIL-nonFraction-nil-attr-false.xml': 0.054,
    'nonFraction/FAIL-nonFraction-nil-decimal-conflict.xml': 0.057,
    'nonFraction/FAIL-nonFraction-no-format-negative-number.xml': 0.070,
    'nonFraction/FAIL-nonFraction-unresolvable-ix-tupleRef-attr.xml': 0.047,
    'nonFraction/FAIL-nonfraction-rule-no-xbrli-attributes.xml': 0.053,
    'nonFraction/FAIL-unresolvable-contextRef.xml': 0.056,
    'nonFraction/FAIL-unresolvable-unitRef.xml': 0.056,
    'nonFraction/PASS-attribute-ix-format-nonFraction-01.xml': 3.632,
    'nonFraction/PASS-attribute-ix-name-nonFraction-01.xml': 1.717,
    'nonFraction/PASS-attribute-ix-scale-nonFraction-01.xml': 3.763,
    'nonFraction/PASS-attribute-ix-scale-nonFraction-04.xml': 3.736,
    'nonFraction/PASS-attribute-ix-sign-nonFraction-01.xml': 3.749,
    'nonFraction/PASS-element-ix-nonFraction-complete.xml': 1.576,
    'nonFraction/PASS-element-ix-nonFraction-ixt-numcomma.xml': 1.586,
    'nonFraction/PASS-element-ix-nonFraction-ixt-numcommadot.xml': 1.548,
    'nonFraction/PASS-element-ix-nonFraction-ixt-numdash.xml': 1.541,
    'nonFraction/PASS-element-ix-nonFraction-ixt-numdotcomma.xml': 1.543,
    'nonFraction/PASS-element-ix-nonFraction-ixt-numspacecomma.xml': 1.559,
    'nonFraction/PASS-element-ix-nonFraction-ixt-numspacedot.xml': 1.557,
    'nonFraction/PASS-nonFraction-any-attribute.xml': 0.065,
    'nonFraction/PASS-nonFraction-comments.xml': 0.065,
    'nonFraction/PASS-nonFraction-decimals-attr.xml': 0.063,
    'nonFraction/PASS-nonFraction-ix-format-expanded-name-match.xml': 0.064,
    'nonFraction/PASS-nonFraction-ix-format-valid.xml': 0.065,
    'nonFraction/PASS-nonFraction-ix-order-attr.xml': 0.061,
    'nonFraction/PASS-nonFraction-ix-target-attr.xml': 0.116,
    'nonFraction/PASS-nonFraction-ix-tupleRef-attr.xml': 0.061,
    'nonFraction/PASS-nonFraction-nesting-2.xml': 0.059,
    'nonFraction/PASS-nonFraction-nesting-formats-2.xml': 0.063,
    'nonFraction/PASS-nonFraction-nesting-formats.xml': 0.115,
    'nonFraction/PASS-nonFraction-nesting-scale.xml': 0.061,
    'nonFraction/PASS-nonFraction-nesting.xml': 0.060,
    'nonFraction/PASS-nonFraction-precision-attr.xml': 0.056,
    'nonFraction/PASS-nonFraction-processing-instructions.xml': 0.062,
    'nonFraction/PASS-nonFraction-valid-scale-attr.xml': 0.059,
    'nonFraction/PASS-nonFraction-valid-sign-attr.xml': 0.062,
    'nonFraction/PASS-nonFraction-valid-sign-format-attr.xml': 0.060,
    'nonFraction/PASS-nonFraction-xsi-nil-attr.xml': 0.061,
    'nonFraction/PASS-simple-nonFraction.xml': 0.061,
    'nonNumeric/FAIL-element-ix-nonNumeric-escape-01.xml': 1.300,
    'nonNumeric/FAIL-nonNumeric-any-ix-attribute.xml': 0.054,
    'nonNumeric/FAIL-nonNumeric-empty-with-format.xml': 0.052,
    'nonNumeric/FAIL-nonNumeric-illegal-null-namespace-attr.xml': 0.050,
    'nonNumeric/FAIL-nonNumeric-invalid-ix-format-attr.xml': 0.047,
    'nonNumeric/FAIL-nonNumeric-ix-format-attr-wrong-namespace-binding.xml': 0.051,
    'nonNumeric/FAIL-nonNumeric-missing-contextRef-attr.xml': 0.052,
    'nonNumeric/FAIL-nonNumeric-missing-name-attr.xml': 0.051,
    'nonNumeric/FAIL-nonNumeric-no-xbrli-attributes.xml': 0.044,
    'nonNumeric/FAIL-nonNumeric-unresolvable-ix-contextRef.xml': 0.050,
    'nonNumeric/FAIL-nonNumeric-unresolvable-ix-tupleRef-attr.xml': 0.052,
    'nonNumeric/PASS-attribute-ix-extension-illegalPlacement-01.xml': 3.557,
    'nonNumeric/PASS-attribute-ix-name-nonNumeric-01.xml': 1.666,
    'nonNumeric/PASS-element-ix-nonNumeric-complete.xml': 1.507,
    'nonNumeric/PASS-element-ix-nonNumeric-escape-02.xml': 1.506,
    'nonNumeric/PASS-element-ix-nonNumeric-escape-03.xml': 1.507,
    'nonNumeric/PASS-element-ix-nonNumeric-escape-04.xml': 1.518,
    'nonNumeric/PASS-element-ix-nonNumeric-escape-05.xml': 1.528,
    'nonNumeric/PASS-element-ix-nonNumeric-escape-06.xml': 1.487,
    'nonNumeric/PASS-element-ix-nonNumeric-escape-07.xml': 1.490,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datedoteu-01.xml': 1.493,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datedotus-01.xml': 1.498,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datedotus-02.xml': 1.502,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datedotus-03.xml': 1.513,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelongdaymonthuk-01.xml': 1.516,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelongmonthdayus-01.xml': 1.526,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelongmonthyear-01.xml': 1.492,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelonguk-01.xml': 1.510,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelonguk-02.xml': 1.505,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelongus-01.xml': 1.530,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelongus-02.xml': 1.516,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-datelongyearmonth-01.xml': 1.531,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortdaymonthuk-01.xml': 1.506,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortmonthdayus-01.xml': 1.537,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortmonthyear-01.xml': 1.489,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortuk-01.xml': 1.496,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortuk-02.xml': 1.504,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortus-01.xml': 1.507,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortus-02.xml': 1.510,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateshortyearmonth-01.xml': 1.483,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslashdaymontheu-01.xml': 1.487,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslasheu-01.xml': 1.490,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslasheu-02.xml': 1.495,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslasheu-03.xml': 1.520,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslashmonthdayus-01.xml': 1.525,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslashus-01.xml': 1.519,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslashus-02.xml': 1.525,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslashus-03.xml': 1.493,
    'nonNumeric/PASS-element-ix-nonNumeric-ixt-dateslashus-04.xml': 1.499,
    'nonNumeric/PASS-element-ordering.xml': 1.496,
    'nonNumeric/PASS-nonNumeric-any-attribute.xml': 0.061,
    'nonNumeric/PASS-nonNumeric-empty-not-xsi-nil.xml': 0.058,
    'nonNumeric/PASS-nonNumeric-escape-with-html-base.xml': 1.502,
    'nonNumeric/PASS-nonNumeric-ix-format-attr-expanded-name-match.xml': 0.060,
    'nonNumeric/PASS-nonNumeric-ix-format-attr.xml': 0.058,
    'nonNumeric/PASS-nonNumeric-ix-order-attr.xml': 0.068,
    'nonNumeric/PASS-nonNumeric-ix-target-attr.xml': 0.119,
    'nonNumeric/PASS-nonNumeric-ix-tupleRef-attr.xml': 0.057,
    'nonNumeric/PASS-nonNumeric-nesting-in-exclude.xml': 0.058,
    'nonNumeric/PASS-nonNumeric-nesting-numerator.xml': 0.058,
    'nonNumeric/PASS-nonNumeric-nesting-text-in-exclude.xml': 0.059,
    'nonNumeric/PASS-nonNumeric-nesting.xml': 0.107,
    'nonNumeric/PASS-nonNumeric-xsi-nil.xml': 0.054,
    'nonNumeric/PASS-nonNumeric.xml': 0.059,
    'references/FAIL-empty-references.xml': 0.039,
    'references/FAIL-ix-references-03.xml': 1.277,
    'references/FAIL-ix-references-08.xml': 1.388,
    'references/FAIL-ix-references-09.xml': 1.405,
    'references/FAIL-ix-references-namespace-bindings-01.xml': 1.384,
    'references/FAIL-ix-references-namespace-bindings-02.xml': 1.404,
    'references/FAIL-ix-references-namespace-bindings-03.xml': 1.394,
    'references/FAIL-ix-references-namespace-bindings-04.xml': 1.418,
    'references/FAIL-ix-references-rule-multiple-attributes-sameValue.xml': 1.317,
    'references/FAIL-ix-references-rule-multiple-id.xml': 1.312,
    'references/FAIL-missing-references-for-all-target-documents.xml': 0.044,
    'references/FAIL-missing-references.xml': 0.035,
    'references/FAIL-references-illegal-content.xml': 0.050,
    'references/FAIL-references-illegal-location.xml': 0.043,
    'references/FAIL-references-illegal-order-in-header.xml': 0.051,
    'references/PASS-element-ix-references-01.xml': 1.489,
    'references/PASS-ix-references-01.xml': 1.500,
    'references/PASS-ix-references-02.xml': 1.508,
    'references/PASS-ix-references-04.xml': 1.623,
    'references/PASS-ix-references-05.xml': 1.617,
    'references/PASS-ix-references-rule-multiple-matched-target.xml': 1.651,
    'references/PASS-ix-references-rule-multiple-xmlBase.xml': 0.060,
    'references/PASS-references-copy-non-ix-attrs.xml': 0.059,
    'references/PASS-references-ix-target-attr.xml': 0.113,
    'references/PASS-simple-linkbaseRef.xml': 0.054,
    'references/PASS-simple-schemaRef.xml': 0.059,
    'references/PASS-single-references-multi-input.xml': 0.096,
    'relationships/FAIL-relationship-cross-duplication.xml': 0.047,
    'relationships/FAIL-relationship-mixes-footnote-with-explanatory-fact.xml': 0.053,
    'relationships/FAIL-relationship-with-no-namespace-attribute.xml': 0.048,
    'relationships/FAIL-relationship-with-xbrli-attribute.xml': 0.050,
    'relationships/FAIL-relationship-with-xlink-attribute.xml': 0.043,
    'relationships/PASS-explanatory-fact-copy-to-owner-target.xml': 0.110,
    'relationships/PASS-explanatory-fact-cycle.xml': 0.062,
    'relationships/PASS-explanatory-fact-not-hidden.xml': 0.057,
    'relationships/PASS-explanatory-fact.xml': 0.056,
    'relationships/PASS-relationship-to-multiple-explanatory-facts-multiple-outputs.xml': 0.117,
    'relationships/PASS-relationship-to-multiple-explanatory-facts.xml': 0.055,
    'relationships/PASS-relationship-with-xml-base.xml': 0.053,
    'relationships/PASS-tuple-footnotes.xml': 0.057,
    'resources/FAIL-context-without-id.xml': 0.050,
    'resources/FAIL-missing-resources.xml': 0.048,
    'resources/FAIL-unit-without-id.xml': 0.053,
    'resources/PASS-empty-resources.xml': 0.056,
    'resources/PASS-simple-arcroleRef.xml': 0.057,
    'resources/PASS-simple-roleRef.xml': 0.062,
    'specificationExamples/PASS-section-10.3-example-1.xml': 1.510,
    'specificationExamples/PASS-section-11.3-example-2.xml': 1.504,
    'specificationExamples/PASS-section-15.1-example-3.xml': 1.629,
    'specificationExamples/PASS-section-15.1-example-4.xml': 1.625,
    'transformations/FAIL-invalid-long-month.xml': 0.053,
    'transformations/FAIL-invalid-short-month.xml': 0.043,
    'transformations/FAIL-unrecognised-schema-type.xml': 0.098,
    'transformations/PASS-sign-attribute-on-nonFraction-positive-input.xml': 0.061,
    'tuple/FAIL-badly-formatted-order-attr.xml': 0.052,
    'tuple/FAIL-badly-nested-tuples.xml': 0.051,
    'tuple/FAIL-duplicate-order-and-value-but-not-attributes.xml': 0.051,
    'tuple/FAIL-duplicate-tuple-id-different-input-docs.xml': 0.088,
    'tuple/FAIL-duplicate-tuple-id.xml': 0.056,
    'tuple/FAIL-duplicate-tuple-order-different-values.xml': 0.051,
    'tuple/FAIL-illegal-element-nested.xml': 0.051,
    'tuple/FAIL-illegal-element.xml': 0.042,
    'tuple/FAIL-missing-descendants.xml': 0.049,
    'tuple/FAIL-nested-tuple-empty.xml': 0.051,
    'tuple/FAIL-order-attr-denominator.xml': 0.049,
    'tuple/FAIL-order-attr-inNonTuple.xml': 0.045,
    'tuple/FAIL-order-attr-numerator.xml': 0.048,
    'tuple/FAIL-ordering-order-duplicate-stringUnequal.xml': 0.052,
    'tuple/FAIL-ordering-order-duplicate.xml': 0.047,
    'tuple/FAIL-ordering-partially-missing.xml': 0.053,
    'tuple/FAIL-orphaned-tuple-content.xml': 0.052,
    'tuple/FAIL-tuple-any-ix-attribute.xml': 0.053,
    'tuple/FAIL-tuple-content-in-different-targets-tuple-not-in-default.xml': 0.049,
    'tuple/FAIL-tuple-content-in-different-targets.xml': 0.047,
    'tuple/FAIL-tuple-cycle-by-tupleRef.xml': 0.050,
    'tuple/FAIL-tuple-cycle-child.xml': 0.048,
    'tuple/FAIL-tuple-cycle-grandchildren.xml': 0.064,
    'tuple/FAIL-tuple-empty-no-ix-tupleID.xml': 0.048,
    'tuple/FAIL-tuple-empty.xml': 0.052,
    'tuple/FAIL-tuple-missing-name-attr.xml': 0.044,
    'tuple/FAIL-tuple-no-xbrli-attributes.xml': 0.052,
    'tuple/FAIL-tuple-unresolvable-footnoteRef-attr.xml': 0.051,
    'tuple/FAIL-tuple-xsi-nil-with-tuple-ref.xml': 0.048,
    'tuple/PASS-attribute-ix-name-tuple-01.xml': 1.585,
    'tuple/PASS-duplicate-order-same-ws-normalized-value-with-html.xml': 0.058,
    'tuple/PASS-duplicate-order-same-ws-normalized-value.xml': 0.060,
    'tuple/PASS-element-ix-tuple-complete.xml': 1.512,
    'tuple/PASS-element-tuple-reference-multiInput.xml': 0.099,
    'tuple/PASS-element-tuple-reference.xml': 0.061,
    'tuple/PASS-exotic-tuple-order.xml': 0.056,
    'tuple/PASS-nested-tuple-ix-order-no-tupleRef.xml': 0.060,
    'tuple/PASS-nested-tuple-nonEmpty.xml': 0.061,
    'tuple/PASS-nested-tuple.xml': 0.059,
    'tuple/PASS-nonFraction-nesting-reference-conflict.xml': 0.062,
    'tuple/PASS-ordering-references-nesting-order.xml': 0.057,
    'tuple/PASS-singleton-tuple.xml': 0.059,
    'tuple/PASS-tuple-all-content-nested-noTupleID.xml': 0.063,
    'tuple/PASS-tuple-any-attribute.xml': 0.107,
    'tuple/PASS-tuple-ix-target-attr.xml': 0.126,
    'tuple/PASS-tuple-nested-nonNumeric.xml': 0.057,
    'tuple/PASS-tuple-nesting-reference-conflict.xml': 0.058,
    'tuple/PASS-tuple-nonInteger-ordering-nested.xml': 0.062,
    'tuple/PASS-tuple-ordering-nested.xml': 0.057,
    'tuple/PASS-tuple-scope-inverted-siblings.xml': 0.060,
    'tuple/PASS-tuple-scope-inverted.xml': 0.058,
    'tuple/PASS-tuple-scope-nested-nonNumeric.xml': 0.060,
    'tuple/PASS-tuple-scope-nonNumeric.xml': 0.060,
    'tuple/PASS-tuple-xsi-nil.xml': 0.059,
    'xmllang/FAIL-xml-lang-not-in-scope-for-footnote.xml': 0.051,
    'xmllang/FAIL-xml-lang-on-ix-hidden-and-on-footnote.xml': 0.050,
    'xmllang/FAIL-xml-lang-on-ix-hidden.xml': 0.059,
    'xmllang/PASS-direct-xml-lang-not-overidden.xml': 0.058,
    'xmllang/PASS-xml-lang-on-xhtml.xml': 0.059,
}.items()}

ZIP_PATH = 'inlineXBRL-1.1-conformanceSuite-2020-04-08.zip'
# needs to be extracted because arelle can't load a taxonomy package ZIP from within a ZIP
EXTRACTED_PATH = ZIP_PATH.replace('.zip', '')
config = ConformanceSuiteConfig(
    approximate_relative_timing=TIMING,
    args=[
        '--packages', os.path.join(CONFORMANCE_SUITE_PATH_PREFIX, EXTRACTED_PATH, 'inlineXBRL-1.1-conformanceSuite-2020-04-08/schemas/www.example.com.zip'),
    ],
    capture_warnings=False,
    extract_path=EXTRACTED_PATH,
    file='inlineXBRL-1.1-conformanceSuite-2020-04-08/index.xml',
    info_url='https://specifications.xbrl.org/work-product-index-inline-xbrl-inline-xbrl-1.1.html',
    local_filepath=ZIP_PATH,
    name=PurePath(__file__).stem,
    network_or_cache_required=False,
    plugins=frozenset({'inlineXbrlDocumentSet', '../../tests/plugin/testcaseIxExpectedHtmlFixup.py'}),
    public_download_url='https://www.xbrl.org/2020/inlineXBRL-1.1-conformanceSuite-2020-04-08.zip',
    shards=4,
)
