from pathlib import PurePath
from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig

TIMING = {
    'br_kvk/2-04-testcase.xml': 6.364,
    'br_kvk/3-01-testcase.xml': 13.398,
    'br_kvk/4-07-testcase.xml': 6.878,
    'br_kvk/4-10-testcase.xml': 6.826,
    'br_kvk/4-12-testcase.xml': 7.250,
    'br_kvk/4-16-testcase.xml': 7.260,
    'br_kvk/4-17-testcase.xml': 1.161,
    'br_kvk/4-20-testcase.xml': 6.778,
    'fg_nl/04-testcase.xml': 0.011,
    'fg_nl/05-testcase.xml': 0.038,
    'fg_nl/09-testcase.xml': 0.343,
    'fg_nl/11-testcase.xml': 0.011,
    'fr_kvk/1-01-testcase.xml': 6.457,
    'fr_kvk/2-01-testcase.xml': 14.355,
    'fr_kvk/2-03-testcase.xml': 0.003,
    'fr_kvk/5-01-testcase.xml': 7.117,
    'fr_kvk/5-02-testcase.xml': 7.063,
    'fr_nl/1-01-testcase.xml': 0.007,
    'fr_nl/1-02-testcase.xml': 0.060,
    'fr_nl/1-03-testcase.xml': 0.011,
    'fr_nl/1-04-testcase.xml': 0.004,
    'fr_nl/1-05-testcase.xml': 0.080,
    'fr_nl/1-06-testcase.xml': 0.003,
    'fr_nl/2-03-testcase.xml': 0.296,
    'fr_nl/2-04-testcase.xml': 0.012,
    'fr_nl/2-05-testcase.xml': 0.011,
    'fr_nl/2-06-testcase.xml': 0.057,
    'fr_nl/2-07-testcase.xml': 1.979,
    'fr_nl/3-01-testcase.xml': 0.841,
    'fr_nl/3-02-testcase.xml': 0.799,
    'fr_nl/3-03-testcase.xml': 0.801,
    'fr_nl/3-04-testcase.xml': 2.512,
    'fr_nl/4-01-testcase.xml': 1.697,
    'fr_nl/4-02-testcase.xml': 0.873,
    'fr_nl/5-01-testcase.xml': 1.719,
    'fr_nl/5-03-testcase.xml': 0.873,
    'fr_nl/5-06-testcase.xml': 0.843,
    'fr_nl/5-11-testcase.xml': 0.057,
    'fr_nl/6-01-testcase.xml': 0.854,
}

config = ConformanceSuiteConfig(
    approximate_relative_timing=TIMING,
    args=[
        '--disclosureSystem', 'NT17-preview',
    ],
    file='index.xml',
    info_url='https://sbr-nl.nl/sites/default/files/bestanden/taxonomie/SBR%20Filing%20Rules%20NT17%20-%2020220301__.pdf',
    local_filepath='nl_nt17',
    name=PurePath(__file__).stem,
    plugins=frozenset({'validate/NL'}),
    shards=4,
)
