from pathlib import PurePath
from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig

TIMING = {
    'br_kvk/2-04-testcase.xml': 6.145,
    'br_kvk/3-01-testcase.xml': 13.028,
    'br_kvk/4-07-testcase.xml': 6.638,
    'br_kvk/4-10-testcase.xml': 6.841,
    'br_kvk/4-12-testcase.xml': 6.916,
    'br_kvk/4-16-testcase.xml': 6.880,
    'br_kvk/4-17-testcase.xml': 0.724,
    'br_kvk/4-20-testcase.xml': 7.116,
    'fg_nl/04-testcase.xml': 0.011,
    'fg_nl/05-testcase.xml': 0.041,
    'fg_nl/09-testcase.xml': 0.043,
    'fg_nl/11-testcase.xml': 0.090,
    'fr_kvk/1-01-testcase.xml': 7.031,
    'fr_kvk/2-01-testcase.xml': 14.035,
    'fr_kvk/2-03-testcase.xml': 0.005,
    'fr_kvk/5-01-testcase.xml': 7.224,
    'fr_kvk/5-02-testcase.xml': 7.283,
    'fr_nl/1-01-testcase.xml': 0.017,
    'fr_nl/1-02-testcase.xml': 0.002,
    'fr_nl/1-03-testcase.xml': 0.001,
    'fr_nl/1-04-testcase.xml': 0.005,
    'fr_nl/1-05-testcase.xml': 0.001,
    'fr_nl/1-06-testcase.xml': 0.003,
    'fr_nl/2-03-testcase.xml': 0.003,
    'fr_nl/2-04-testcase.xml': 0.008,
    'fr_nl/2-05-testcase.xml': 0.106,
    'fr_nl/2-06-testcase.xml': 0.170,
    'fr_nl/2-07-testcase.xml': 1.993,
    'fr_nl/3-01-testcase.xml': 0.780,
    'fr_nl/3-02-testcase.xml': 0.867,
    'fr_nl/3-03-testcase.xml': 0.834,
    'fr_nl/3-04-testcase.xml': 2.372,
    'fr_nl/4-01-testcase.xml': 1.633,
    'fr_nl/4-02-testcase.xml': 0.845,
    'fr_nl/5-01-testcase.xml': 1.638,
    'fr_nl/5-03-testcase.xml': 0.806,
    'fr_nl/5-06-testcase.xml': 0.832,
    'fr_nl/5-11-testcase.xml': 0.031,
    'fr_nl/6-01-testcase.xml': 0.812,
}

config = ConformanceSuiteConfig(
    approximate_relative_timing=TIMING,
    args=[
        '--disclosureSystem', 'NT16-preview',
    ],
    file='index.xml',
    info_url='https://sbr-nl.nl/sites/default/files/bestanden/taxonomie/SBR%20Filing%20Rules%20NT16%20-%2020210301_0.pdf',
    local_filepath='nl_nt16',
    name=PurePath(__file__).stem,
    plugins=frozenset({'validate/NL'}),
    shards=4,
)
